@@ -7,9 +7,9 @@ import ckan.plugins.toolkit as tk
 
 from . import QueryScore, normalize_query, update_score_by_url
 
-from .. import cli
+from ..cli import attach_relevance_command
 from ..interfaces import ISearchTweaks
-
+from . import cli
 
 CONFIG_BOOST_STRING = "ckanext.search_tweaks.query_relevance.boost_function"
 CONFIG_RELEVANCE_PREFIX = "ckanext.search_tweaks.query_relevance.field_prefix"
@@ -23,18 +23,20 @@ class QueryRelevancePlugin(plugins.SingletonPlugin):
     plugins.implements(plugins.IPackageController, inherit=True)
     plugins.implements(ISearchTweaks, inherit=True)
 
-    # iConfigurable
+    # IConfigurable
 
     def configure(self, config):
-        cli.search_tweaks.add_command(cli.relevance)
+        attach_relevance_command(cli.query)
 
     # IPackageController
 
     def before_index(self, pkg_dict):
         prefix = tk.config.get(CONFIG_RELEVANCE_PREFIX, DEFAULT_RELEVANCE_PREFIX)
+
         for (_, query, score) in QueryScore.get_for(pkg_dict["id"]):
             query = query.replace(" ", "_")
             pkg_dict[prefix + query] = score
+
         return pkg_dict
 
     def read(self, entity):
@@ -52,13 +54,17 @@ class QueryRelevancePlugin(plugins.SingletonPlugin):
                 "ext_search_tweaks_disable_relevance", False
             )
         )
+
         if not search_params.get("q") or disabled:
             return None
+
         normalized = normalize_query(search_params["q"]).replace(" ", "_")
         if not normalized:
             return None
+
         field = prefix + normalized
         boost_string = Template(
             tk.config.get(CONFIG_BOOST_STRING, DEFAULT_BOOST_STRING)
         )
+
         return boost_string.safe_substitute({"field": field})
